async fn connect_to_server(
    relay: Arc<String>,
    files: Arc<Vec<String>>,
    room_id: Option<String>,
    message_server: Arc<String>,
    transfer_name: Arc<String>,
    tx: Sender<()>,
    is_local: bool
)
Connects to the specified server and starts the file transfer.

Arguments

  • relay - The relay server URL.
  • files - The files to be transferred.
  • room_id - The room ID for the transfer. If None, a random UUID is generated.
  • message_server - The message server URL.
  • transfer_name - The name of the transfer.
  • tx - The sender end of a channel to signal the completion of the transfer.
  • is_local - Whether the transfer is local or not.